@@ -1,13 +1,9 @@
-import sys
-from openapi_client import Configuration, ApiException
 from rich.table import Table
 from rich import box
 import typer
 
 from threedi_cmd.commands.settings import (
-    EndpointOption,
     ScenariosMeta,
-    get_settings,
 )
 from threedi_cmd.commands.callbacks import default_callback
 from threedi_cmd.console import console
@@ -25,9 +21,7 @@ scenario_app = typer.Typer(callback=default_callback)
 def scenarios(ctx: typer.Context):
     """List local scenarios"""
     table = Table(show_header=True, box=box.HORIZONTALS, show_lines=True)
-    table.add_column(
-        "Id", width=5
-    )
+    table.add_column("Id", width=5)
     table.add_column(
         "Name",
         width=20,
@@ -39,9 +33,7 @@ def scenarios(ctx: typer.Context):
     table.add_column(
         "Caution", justify="left", style="orange3", header_style="bold orange3"
     )
-    table.add_column(
-        "yaml", justify="left", style="dim blue", header_style="bold blue"
-    )
+    table.add_column("yaml", justify="left", style="dim blue", header_style="bold blue")
     s = ScenariosMeta(ctx.obj.scenario_folder)
     for i, scenario in enumerate(s.scenarios, start=0):
         if isinstance(scenario, dict):
@@ -60,4 +52,4 @@ def scenarios(ctx: typer.Context):
 
 
 if __name__ == "__main__":
-    scenario_app()
\ No newline at end of file
+    scenario_app()
