@@ -20,16 +20,12 @@ from threedi_api_client.aio.threedi_api_client import (
 )
 
 try:
-    from threedi_api_client.auth import (
-        get_auth_token,
-        refresh_api_key,
-        is_token_usable
-    )
+    from threedi_api_client.auth import get_auth_token, refresh_api_key, is_token_usable
 except ImportError:
     from threedi_api_client.threedi_api_client import (
         get_auth_token,
         refresh_api_key,
-        is_token_usable
+        is_token_usable,
     )
 
 from threedi_cmd.console import console
@@ -293,6 +289,6 @@ class Settings:
         # Update the settings
         self.username = username
         self.password = password
-        self.access = token.access
-        self.refresh = token.refresh
-        config.api_key = {"Authorization": token.access, "refresh": token.refresh}
+        self.access = token["access"]
+        self.refresh = token["refresh"]
+        config.api_key = {"Authorization": self.access, "refresh": self.refresh}
