@@ -9,8 +9,8 @@ import json
 
 import typer
 from threedi_api_client.openapi.api import V3Api
-from threedi_api_client.threedi_api_client import ThreediApiClient
 from threedi_api_client.api import ThreediApi
+from threedi_api_client.openapi.models import ThreediModel
 import yaml
 from rich.table import Table
 from rich.padding import Padding
@@ -169,7 +169,9 @@ class Suite:
         self.report = Report(endpoint=self.endpoint, scenarios=self.scenarios)
 
     @classmethod
-    def resolve_model(cls, scenario_name, model_api, values, resolved_models):
+    def resolve_model(
+        cls, scenario_name, model_api, values, resolved_models
+    ) -> ThreediModel:
         model = None
 
         if "threedimodel_filter" in values:
@@ -192,12 +194,10 @@ class Suite:
                         f"! multiple models found for lookup: {values['threedimodel_filter']}",
                         style="warning",
                     )
-                model = res.results[0].id
-
+                model = res.results[0]
                 resolved_models[cache_key] = model
-
         elif "threedimodel_id" in values:
-            model = values["threedimodel_id"]
+            model = model_api.threedimodels_read(values["threedimodel_id"])
         else:
             print(f"No model defined for scenario: {scenario_name}")
         return model
@@ -277,7 +277,8 @@ class Suite:
                 )
 
                 context = {
-                    "threedimodel_id": model,
+                    "threedimodel_id": model.id,
+                    "threedimodel": model,
                     "organisation_uuid": organisation_uuid,
                     "simulation_name": key,
                     "datetime_now": datetime.utcnow().isoformat(),
