@@ -163,6 +163,33 @@ class SimulationWrapper(ModelWrapper):
     api_path = "simulations"
 
 
+class SimulationTemplateWrapper(ModelWrapper):
+    model = Simulation
+    api_path = "simulations_from_template"
+
+    def initialize_instance(self, data):
+        pass
+
+    def resolve_func_name(self, suffix: str):
+        func = getattr(self._api_client, f"{self.api_path}")
+        return func
+
+    def save(self):
+        id = getattr(self.instance, "id", None)
+        if id is not None:
+            return
+
+        with Live(console=console) as live:
+            live.update(f"Creating {self.model.__name__}...")
+            func = self.resolve_func_name("")
+            res = func(self._data)
+            live.update(
+                f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
+            )
+        console.print(res, type(res))
+        self.instance = res
+
+
 class SchematisationWrapper(ModelWrapper):
     model = Schematisation
     api_path = "schematisations"
