@@ -26,7 +26,7 @@ class RasterEditWrapper(EventWrapper):
             # Try to lookup/find the raster.
             api: V3Api = self._api_client
             res = api.threedimodels_rasters_list(
-                self.simulation.threedimodel, type=self.raster_type
+                self.simulation.threedimodel_id, type=self.raster_type
             )
             if res.count != 1:
                 raise RasterEditError(
