@@ -11,8 +11,7 @@ def discover() -> AppRegistry:
 
     discovered_plugins = {
         name: importlib.import_module(name)
-        for finder, name, is_pkg
-        in pkgutil.iter_modules()
+        for finder, name, is_pkg in pkgutil.iter_modules()
         if name.startswith(PLUGIN_NAME_PREFIX)
     }
     registry = AppRegistry({})
